@@ -1,3 +1,4 @@
+import augmenty
 from augmenty.keyboard import Keyboard
 
 
@@ -10,3 +11,7 @@ def test_Keyboard():
     assert len(set(kb.all_keys())) > 28 * 2
     assert "w" in kb.get_neighbours("q")
     kb.create_distance_dict()
+
+    for keyboard in augmenty.keyboards():
+        kb = Keyboard.from_registry(keyboard)
+
