@@ -1,6 +1,6 @@
 import random
 from functools import partial
-from typing import Dict, Iterator, Callable, List, Union
+from typing import Dict, Iterator, Callable, List, Optional, Union
 
 import spacy
 from spacy.language import Language
@@ -14,6 +14,7 @@ from ..augment_utilities import make_text_from_orth
 def create_token_replace_augmenter(
     level: float,
     replace: Union[Dict[str, List[str]], Dict[str, Dict[str, List[str]]]],
+    ignore_casing: bool = True,
     getter: Callable[[Token], str] = lambda token: token.pos_,
 ) -> Callable[[Language, Example], Iterator[Example]]:
     """Creates an augmenter swaps a token with its synonym based on a dictionary.
@@ -23,6 +24,7 @@ def create_token_replace_augmenter(
         replace (Union[Dict[str, List[str]], Dict[str, Dict[str, List[str]]]]): A dictionary of
             words and a list of their replacement (e.g. synonyms) or a dictionary denoting
             replacement based on pos tag.
+        ignore_casing: When doing the lookup should the model ignore casing? Defaults to True.
         getter (Callable[[Token], str], optional): A getter function to extract the POS-tag.
 
     Returns:
@@ -35,7 +37,11 @@ def create_token_replace_augmenter(
         >>> replace = {"act": {"VERB": ["perform", "move"], "NOUN": ["action", "deed"]}}
         >>> create_token_replace_augmenter(replace=replace, level=.10)
     """
-    return partial(token_replace_augmenter, level=level, replace=replace, getter=getter)
+    if ignore_casing is True:
+        for k in replace:
+            replace[k.lower()] = replace[k]
+            
+    return partial(token_replace_augmenter, level=level, replace=replace, getter=getter, ignore_casing=ignore_casing)
 
 
 def token_replace_augmenter(
@@ -43,10 +49,14 @@ def token_replace_augmenter(
     example: Example,
     level: float,
     replace: Union[Dict[str, List[str]], Dict[str, Dict[str, List[str]]]],
+    ignore_casing: bool,
     getter: Callable[[Token], str],
 ) -> Iterator[Example]:
     def __replace(t):
-        if t.text in replace and random.random() < level:
+        text = t.text
+        if ignore_casing is True:
+            text = text.lower()
+        if text in replace and random.random() < level:
             if isinstance(replace[t.text], dict):
                 pos = getter(t)
                 if pos in replace[t.text]:
@@ -64,13 +74,15 @@ def token_replace_augmenter(
 
 @spacy.registry.augmenters("wordnet_synonym.v1")
 def create_wordnet_synonym_augmenter(
-    level: float, lang: str, getter: Callable = lambda token: token.pos_
+    level: float, lang: Optional[str] = None, getter: Callable = lambda token: token.pos_
 ) -> Callable[[Language, Example], Iterator[Example]]:
     """Creates an augmenter swaps a token with its synonym based on a dictionary.
 
     Args:
-        lang (str): Language supplied a ISO 639-1 language code. Possible langauge include
-        "da", "ca", "en", "eu", "fa", "fi", "fr", "gl", "he", "id", "it", "ja", "nn", "no", "pl", "pt", "es", "th".
+        lang (Optional[str], optional): Language supplied a ISO 639-1 language code. Defaults to None, 
+            in which case the lang is based on the language of the spacy nlp pipeline used.
+            Possible language codes include:
+            "da", "ca", "en", "eu", "fa", "fi", "fr", "gl", "he", "id", "it", "ja", "nn", "no", "pl", "pt", "es", "th".
         level (float): Probability to replace token given that it is in synonym dictionary.
 
     Returns:
@@ -80,6 +92,9 @@ def create_wordnet_synonym_augmenter(
         >>> english_synonym_augmenter = create_wordnet_synonym_augmenter(level=0.1, lang="en")
     """
     try:
+        from nltk import download
+        download("wordnet", quiet=True, raise_on_error=True)
+        download("omw", quiet=True, raise_on_error=True)
         from nltk.corpus import wordnet
     except ModuleNotFoundError as e:
         print(e)
@@ -119,9 +134,12 @@ def create_wordnet_synonym_augmenter(
         nlp: Language,
         example: Example,
         level: float,
-        lang: str,
+        lang: Optional[str],
         getter: Callable,
     ) -> Iterator[Example]:
+        if lang is None:
+            lang = nlp.lang
+
         def __replace(t):
             word = t.text
             if random.random() < level and getter(t) in upos_wn_dict:
